@@ -1,8 +1,9 @@
 package AnyEvent::ProcessPool::Pipeline;
 # ABSTRACT: A simplified, straightforward way to parallelize tasks
-$AnyEvent::ProcessPool::Pipeline::VERSION = '0.06_001'; # TRIAL
+$AnyEvent::ProcessPool::Pipeline::VERSION = '0.02';
 
-$AnyEvent::ProcessPool::Pipeline::VERSION = '0.06001';use common::sense;
+use strict;
+use warnings;
 use AnyEvent::ProcessPool;
 use Try::Catch;
 
@@ -14,12 +15,12 @@ sub pipeline (%) {
   my %param = @_;
   my $in    = delete $param{in};
   my $out   = delete $param{out};
-  my $pool  = delete $param{pool} || AnyEvent::ProcessPool->new(%param);
+  my $pool  = AnyEvent::ProcessPool->new(%param);
   my $count = 0;
 
   my %pending;
-  while (my @task = $in->()) {
-    my $cv = $pool->async(@task);
+  while (defined(my $task = $in->())) {
+    my $cv = $pool->async($task);
     $pending{$cv} = $cv;
     $cv->cb(sub{ ++$count; $out->(shift) });
   }
@@ -46,7 +47,7 @@ AnyEvent::ProcessPool::Pipeline - A simplified, straightforward way to paralleli
 
 =head1 VERSION
 
-version 0.06_001
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -54,8 +55,7 @@ version 0.06_001
 
   pipeline workers => 4,
     in {
-      my @task = get_next_task(); # list of (CODE ref $task, ARRAY ref $args)
-      return @task;
+      get_next_task();
     },
     out {
       process_result(shift->recv);
@@ -65,44 +65,26 @@ version 0.06_001
 
 =head2 pipeline
 
+=over
+
+=item in
+
+=item out
+
+=back
+
 Launches an L<AnyEvent::ProcessPool> and immediately starts processing tasks it
 receives when executing the code specified by C<in>. As results arrive (and not
 necessarily in the order in which they were queued), they are delivered as
 L<condition variables|AnyEvent/CONDITION VARIABLES> (ready ones, guaranteed not
 to block) via the code supplied by C<out>. The pipeline will continue to run
-until C<in> returns an empty list, after which it will continue to run until
-all pending results have been delivered. C<pipeline> returns the total number
-of tasks processed.
-
-Optionally, an existing pool may be specified using the C<pool> parameter.
-
-  pipeline pool => $pool,
-    in  {...},
-    out {...};
+until C<in> returns C<undef>, after which it will continue to run until all
+pending results have been delivered. C<pipeline> returns the total number of
+tasks processed.
 
 Aside from C<in> and C<out>, all other arguments are passed unchanged to
 L<AnyEvent::ProcessPool>'s constructor.
 
-=over
-
-=item in
-
-Supplies the pipeline with a code ref representing the caller's task queue.
-When called, the code ref returns a two item list containing: 1) a code ref to
-be executed in a worker sub-process, and, 2) an (optional) array of arguments
-to be passed to the code ref when called.
-
-The pipeline will call C<in> until an empty list is returned, after which the
-pool will continue to run until all remaining tasks have completed and been
-passed to C<out>.
-
-=item out
-
-Specifies the callback to which results are passed. Results may arrive in any
-order.
-
-=back
-
 =head1 AUTHOR
 
 Jeff Ober <sysread@fastmail.fm>
